===================================================================
PyGridFit: A Python Implementation of Surface Fitting using GridFit
===================================================================

PyGridFit is a Python implementation of the MATLAB Surface Fitting library
GridFit_.

.. image:: example.png
  :alt: Example surface fitted by GridFit.

To install from PyPI::

  pip install gridfit

* Free software: BSD license
* Documentation: https://neural.readthedocs.io.


.. _GridFit: https://www.mathworks.com/matlabcentral/fileexchange/8998-surface-fitting-using-gridfit